##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 5                                                              #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################



######################################
# Section 5.1                        #
######################################
DiCarlo <- data.frame(NoSold = 0:5, 
                      Days = c(54, 117, 72, 42, 12, 3))
DiCarlo
N <- sum(DiCarlo$Days)
DiCarlo$Prob.Sold <- DiCarlo$Days/N
DiCarlo
attach(DiCarlo)

# Expected Value
mu <- sum(NoSold * Prob.Sold)
mu

# Variance
sigma2 <- sum((NoSold - mu)^2 * Prob.Sold)
sigma2



######################################
# Section 5.5                        #
######################################

# Martin Clothing Store Problem
# X ~B(n , p)
Purchase <- c("S", "F")
n <- 3
p <- 0.3

dbinom.tb <- data.frame(x = 0:n, fx = dbinom(0:n, n, p))
dbinom.tb
plot(dbinom.tb, type = "h", lwd = 3)

# X ~ B(10, 0.4), f(3)
dbinom(x = 3, size = 10, prob = 0.4)

# X ~ B(10, 0.4), P( X <= 3)
pbinom(q = 3, size = 10, prob = 0.4)

# X ~ B(10, 0.4), f(q) = 0.2149908 => q = 3
qbinom(p = 0.2149908, size = 10, prob = 0.4)

# X ~ B(10, 0.4), x1, x2, ..., xn iid from X
rbinom(n = 5, size = 10, prob = 0.4)



######################################
# Section 5.6                        #
######################################

# X ~ Poi(10), f(x), x = 0, 1, 2, ...
mu <- 10
dpois.tb <- data.frame(x = 0:5, dpois = round(dpois(x = 0:5, lambda = mu), 4))
dpois.tb
plot(dpois.tb, type = "h", lwd = 3)

# X ~ Poi(10), F(5) = P(X <= 5)
ppois(q = 5, lambda = 10)

# X ~ Poi(10), f(q) = 0.0378
qpois(p = 0.0378, lambda = 10)

# X ~ Poi(10), x1, x2,..., x7 iid X
rpois(7, lambda = 10)



######################################
# Section 5.7                        #
######################################

# X ~ Hyper(N = 12, r = 5, n = 3)
N <- 12 # N
m <- 5 # r
k <- 3 # n
n <- N - m 

# f(0), f(1)     
dhyper(0, m, n, k)
dhyper(1, m, n, k)

# F(x) = P( X <= 1)
phyper(1, m, n, k)

# mean
p <- m/(m+n)
k * p

x <- 0:k
fx <- dhyper(x, m, n, k)
mu <- sum(x * fx)
mu

# variance
k * p * (1 - p) * (m + n - k)/(m + n - 1)

sum( (x - mu)^2 * fx)

